Skip to contents

Invalidates the current DNAnexus session on the remote platform. The local token file is not removed but becomes invalid. A new token must be generated from the DNAnexus platform before calling auth_login() again.

Usage

auth_logout()

Value

Invisible TRUE on success.

Examples

if (FALSE) { # \dontrun{
auth_logout()
} # }