Get pre-authenticated download URL(s) for a remote RAP file or folder
Source:R/fetch.R
fetch_url.RdGenerates temporary HTTPS URLs for files on the DNAnexus Research Analysis Platform. For a single file, returns one URL. For a folder, lists all files inside and returns a named character vector of URLs. This function must be called from within RAP, as a pre-authenticated URL is itself a means of retrieving the underlying file.